#!/bin/bash
#PBS -N chlg2R3.5S0_5
#PBS -l nodes=1:ppn=2:sse
#PBS -S /bin/bash
#PBS -r n
#PBS -j oe
#
# rungmx.bash
# -- generated from rungmx.bash.in ---
# $Id: rungmx.bash.in,v 1.9 2001/11/21 17:03:38 oliver Exp $
#
# this script can be submitted to the PBS queuing system with
#    qsub rungmx.bash

function die () {
#   die "stage" "message" "errorcode"
    local stage=$1 msg=$2 err=$3;

    echo "[$stage]: FATAL -- $msg";
    # notify thru qdb
    echo "$(date) <${PBS_JOBNAME}> <${PBS_JOBID}> DIED  <${HOSTNAME}:${SCRATCH}> [$stage]:${msg} (${err})" >> ${QDB}

    # mark in dir
    echo "$(date) <${PBS_JOBNAME}> <${PBS_JOBID}> DIED  <${HOSTNAME}:${SCRATCH}> [$stage]:${msg} (${err})" > ${err}_${stage}

    exit $err;
};

# on torpedo
# qdb contains notes about where/when-abouts of jobs
QDB=/home/oliver/.qdb

# scratch directories that are visible on all computers:
# run from my own directory on /sansom/gfij/oliver (raid array)
# somehow mkdir -p fails on creating /sansom/gfij/oliver/xxx
#SCRATCH_ROOT=/sansom/gfij/oliver/Running
# ... so I need a sym link in my HOME dir: Storage -> /sansom/gfij/oliver
# SCRATCH_ROOT=${HOME}/Storage/Running

# local scratch disk (on each node -- normally auto cleaned but currently not)
SCRATCH_ROOT=/scratch/oliver

# or use /sansom/range (auto cleaned after 7d)
SCRATCH_DISK=/sansom/range/oliver

# hold space (move results over there from node)
HOLD_SPACE=/sansom/gfij/oliver/Running/Hold


PATH="${PATH}:/usr/local/lam-6.5.2/bin:/usr/local/bin"
LAMHOME=/usr/local/lam-6.5.2
export PATH LAMHOME

# Choose one of the following depending on whether you want to run gromacs 2 or 3.
# gmx2: csh!!
# source /sansom/kir/gmx/gmx2.0/GMXRC
# source /usr/local/gromacs/GMXRC
#
# use binaries on torpedo:
GMXRC=/usr/local/gromacs-3/i686-pc-linux-gnu/bin/GMXRC.bash

# current compiled gromacs 3.0 in my home dir
# (includes shared libs in libdir there)
#GMXRC=/sansom/gfij/oliver/Gromacs/GMXRC_i686

if test -e ${GMXRC}; then
    . ${GMXRC} 
else
    die "Setup" "Cannot find ${GMXRC}" 1;
fi

# explicit paths for programs:
# otherwise invocations through LAM on other nodes fail
MDRUN=$(which mdrun)
test -x "${MDRUN}" || die "Setup" "MDRUN=${MDRUN} is not executable" 1;

# setting up mpi
lamboot -v $PBS_NODEFILE

# setting up dirs

echo "(0) Setting up directories"
echo "=========================="

SOURCEDIR=/sansom/gfij/oliver/scratch/G2/L_8/3.5/0/full/S0_5 ;
test -e ${SOURCEDIR}  || \
    die "Check_SOURCE" "Sourcedir ${SOURCEDIR} does not exist or is not accessible." 1;

# rely on the Geometrypart as tag
DESCRIPTION=$(echo ${SOURCEDIR} |  sed -e 's,/.*/\(G[0-9]/.*\),\1,');

if mkdir -p ${SCRATCH_ROOT} >/dev/null 2>&1; then
    SCRATCH=${SCRATCH_ROOT}/${DESCRIPTION};
    mkdir -p ${SCRATCH} || \
	die "Mkdir_SCRATCH" "Failed to create LOCAL scratch dir ${SCRATCH}" 1;
    echo "Using my own scratch dir: ${HOSTNAME}:${SCRATCH} ";
else
    SCRATCH=${SCRATCH_DISK}/${DESCRIPTION}
    mkdir -p  ${SCRATCH} || \
	die "Mkdir_SCRATCH" "Failed to create REMOTE scratch dir ${SCRATCH}" 1;
    echo "Need to use NFS scratch dir: ${SCRATCH} ";
fi;

echo "SOURCEDIR = torpedo:${SOURCEDIR}"
echo "SCRATCH   = ${HOSTNAME}:${SCRATCH}"

# copying files
if [ "${SCRATCH}" != "${SOURCEDIR}" ]; then
    echo "Copying files from SOURCEDIR to SCRATCHDIR";
    cp ${SOURCEDIR}/* ${SCRATCH};
else
    echo "Working with files in SOURCEDIR == SCRATCH";
fi;

cd ${SCRATCH}  || \
    die "Chdir_SCRATCH" "Failed to enter SCRATCH=${SCRATCH}" 1;

test -e Makefile || die "Check_MAKEFILE" "Cannot find Makefile in ${SCRATCH}." 1;


# write location and PBS_ID to qdb
echo "$(date) <${PBS_JOBNAME}> <${PBS_JOBID}> START <${HOSTNAME}:${SCRATCH}>" | tee --append ${QDB}



# energy minimisation
# (fails sometimes)

echo "(1) Energy minimisation"
echo "======================="

make emin || \
    die "Energy-min_PREP" "Failed to make mdp file" 2;
make run_emin || \
    die "Energy-min_RUN" "Failed to run emin" 2;



# Molecular Dynamics

echo "(2) Molecular dynamics"
echo "======================"

make md || \
    die "MD_PREP" "Failed to make mdp file" 3;
# running md
mpirun C -v -c2c -np 2 ${MDRUN} -np 2 -v -s chl_md.tpr -deffnm chl_lay_water_md  || \
    die "MD_RUN" "Failed to run MD" 3;

# write location and PBS_ID to qdb
echo "$(date) <${PBS_JOBNAME}> <${PBS_JOBID}> END   <${HOSTNAME}:${SCRATCH}>" | tee --append ${QDB}

# shutting down mpi
lamhalt -v $PBS_NODEFILE

# copying to Run_dir holdspace
HOLD_DIR=${HOLD_SPACE}/${PBS_JOBNAME}/${PBS_JOBID}/${DESCRIPTION}
mkdir -p ${HOLD_DIR} \
    || die "Copy_results" "mkdir ${HOLD_DIR} failed" 5;

tar -cf - -C ${SCRATCH} . | tar -C ${HOLD_DIR} -xvf - \
    || die "Copy_results" "tar from [${SCRATCH}] to [${HOLD_DIR}] failed" 5;
echo "finished writing stuff from ${SCRATCH} to ${HOLD_DIR}"

echo -n "Ended script at "
date

exit 0

